==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/tr/Filter.js <==
({
	"clearFilterDialogTitle": "Süzgeci Kaldır",
	"filterDefDialogTitle": "Süzgeç",
	"ruleTitleTemplate": "Kural ${0}",
	
	"conditionEqual": "eşittir",
	"conditionNotEqual": "eşit değildir",
	"conditionLess": "küçüktür",
	"conditionLessEqual": "küçüktür veya eşittir",
	"conditionLarger": "büyüktür",
	"conditionLargerEqual": "büyüktür veya eşittir",
	"conditionContains": "içerir",
	"conditionIs": "şudur",
	"conditionStartsWith": "şununla başlar",
	"conditionEndWith": "şununla biter",
	"conditionNotContain": "içermez",
	"conditionIsNot": "şu değildir",
	"conditionNotStartWith": "şununla başlamaz",
	"conditionNotEndWith": "şununla bitmez",
	"conditionBefore": "önce",
	"conditionAfter": "sonra",
	"conditionRange": "aralık",
	"conditionIsEmpty": "boş",
	
	"all": "tümü",
	"any": "herhangi biri",
	"relationAll": "tüm kurallar",
	"waiRelAll": "Aşağıdaki tüm kurallarla eşleştir",
	"relationAny": "kuralların herhangi biri",
	"waiRelAny": "Aşağıdaki kuralların herhangi biri ile eşleştir",
	"relationMsgFront": "Eşleştir",
	"relationMsgTail": "",
	"and": "ve",
	"or": "veya",
	
	"addRuleButton": "Kural Ekle",
	"waiAddRuleButton": "Yeni bir kural ekle",
	"removeRuleButton": "Kuralı Kaldır",
	"waiRemoveRuleButtonTemplate": "${0} kuralını kaldır",
	
	"cancelButton": "İptal",
	"waiCancelButton": "Bu iletişim kutusunu iptal et",
	"clearButton": "Kaldır",
	"waiClearButton": "Süzgeci kaldır",
	"filterButton": "Süzgeç",
	"waiFilterButton": "Süzgeci gönder",
	
	"columnSelectLabel": "Sütun",
	"waiColumnSelectTemplate": "${0} kuralı için sütun",
	"conditionSelectLabel": "Koşul",
	"waiConditionSelectTemplate": "${0} kuralı için koşul",
	"valueBoxLabel": "Değer",
	"waiValueBoxTemplate": "${0} kuralı için süzülecek değeri girin",
	
	"rangeTo": "bitiş",
	"rangeTemplate": "${0} - ${1}",
	
	"statusTipHeaderColumn": "Sütun",
	"statusTipHeaderCondition": "Kurallar",
	"statusTipTitle": "Süzgeç Çubuğu",
	"statusTipMsg": "${0} içindeki değerlere göre süzmek için burada süzgeç çubuğunu tıklatın.",
	"anycolumn": "herhangi bir sütun",
	"statusTipTitleNoFilter": "Süzgeç Çubuğu",
	"statusTipTitleHasFilter": "Süzgeç",
	"statusTipRelPre": "Eşleştir",
	"statusTipRelPost": "kurallar.",
	
	"defaultItemsName": "öğe",
	"filterBarMsgHasFilterTemplate": "${0} / ${1} ${2} gösteriliyor.",
	"filterBarMsgNoFilterTemplate": "Süzgeç uygulanmadı",
	
	"filterBarDefButton": "Süzgeç tanımla",
	"waiFilterBarDefButton": "Tabloyu süz",
	"a11yFilterBarDefButton": "Süz...",
	"filterBarClearButton": "Süzgeci kaldır",
	"waiFilterBarClearButton": "Süzgeci kaldır",
	"closeFilterBarBtn": "Süzgeç çubuğunu kapat",
	
	"clearFilterMsg": "Bu seçenek süzgeci kaldırır ve tüm kullanılabilir kayıtları gösterir.",
	"anyColumnOption": "Herhangi Bir Sütun",
	
	"trueLabel": "Doğru",
	"falseLabel": "Yanlış"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/tr/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Süzgeci Kaldır",
	"filterDefDialogTitle": "Süzgeç",
	"ruleTitleTemplate": "Kural ${0}",
	
	"conditionEqual": "eşittir",
	"conditionNotEqual": "eşit değildir",
	"conditionLess": "küçüktür",
	"conditionLessEqual": "küçüktür veya eşittir",
	"conditionLarger": "büyüktür",
	"conditionLargerEqual": "büyüktür veya eşittir",
	"conditionContains": "içerir",
	"conditionIs": "şudur",
	"conditionStartsWith": "şununla başlar",
	"conditionEndWith": "şununla biter",
	"conditionNotContain": "içermez",
	"conditionIsNot": "şu değildir",
	"conditionNotStartWith": "şununla başlamaz",
	"conditionNotEndWith": "şununla bitmez",
	"conditionBefore": "önce",
	"conditionAfter": "sonra",
	"conditionRange": "aralık",
	"conditionIsEmpty": "boş",
	
	"all": "tümü",
	"any": "herhangi biri",
	"relationAll": "tüm kurallar",
	"waiRelAll": "Aşağıdaki tüm kurallarla eşleştir",
	"relationAny": "kuralların herhangi biri",
	"waiRelAny": "Aşağıdaki kuralların herhangi biri ile eşleştir",
	"relationMsgFront": "Eşleştir",
	"relationMsgTail": "",
	"and": "ve",
	"or": "veya",
	
	"addRuleButton": "Kural Ekle",
	"waiAddRuleButton": "Yeni bir kural ekle",
	"removeRuleButton": "Kuralı Kaldır",
	"waiRemoveRuleButtonTemplate": "${0} kuralını kaldır",
	
	"cancelButton": "İptal",
	"waiCancelButton": "Bu iletişim kutusunu iptal et",
	"clearButton": "Kaldır",
	"waiClearButton": "Süzgeci kaldır",
	"filterButton": "Süzgeç",
	"waiFilterButton": "Süzgeci gönder",
	
	"columnSelectLabel": "Sütun",
	"waiColumnSelectTemplate": "${0} kuralı için sütun",
	"conditionSelectLabel": "Koşul",
	"waiConditionSelectTemplate": "${0} kuralı için koşul",
	"valueBoxLabel": "Değer",
	"waiValueBoxTemplate": "${0} kuralı için süzülecek değeri girin",
	
	"rangeTo": "bitiş",
	"rangeTemplate": "${0} - ${1}",
	
	"statusTipHeaderColumn": "Sütun",
	"statusTipHeaderCondition": "Kurallar",
	"statusTipTitle": "Süzgeç Çubuğu",
	"statusTipMsg": "${0} içindeki değerlere göre süzmek için burada süzgeç çubuğunu tıklatın.",
	"anycolumn": "herhangi bir sütun",
	"statusTipTitleNoFilter": "Süzgeç Çubuğu",
	"statusTipTitleHasFilter": "Süzgeç",
	"statusTipRelAny": "Herhangi bir kuralı eşleştir.",
	"statusTipRelAll": "Bütün kuralları eşleştir.",
	
	"defaultItemsName": "öğe",
	"filterBarMsgHasFilterTemplate": "${0} / ${1} ${2} gösteriliyor.",
	"filterBarMsgNoFilterTemplate": "Süzgeç uygulanmadı",
	
	"filterBarDefButton": "Süzgeç tanımla",
	"waiFilterBarDefButton": "Tabloyu süz",
	"a11yFilterBarDefButton": "Süz...",
	"filterBarClearButton": "Süzgeci kaldır",
	"waiFilterBarClearButton": "Süzgeci kaldır",
	"closeFilterBarBtn": "Süzgeç çubuğunu kapat",
	
	"clearFilterMsg": "Bu seçenek süzgeci kaldırır ve tüm kullanılabilir kayıtları gösterir.",
	"anyColumnOption": "Herhangi Bir Sütun",
	
	"trueLabel": "Doğru",
	"falseLabel": "Yanlış"
})
//end v1.x content
);
